#include <gtk/gtk.h>

void
on_window_destroy                      (GtkObject       *object,
                                        gpointer         user_data);

void
on_page0_about_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_page0_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page0_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_register_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_connect_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_next_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_connect_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_credits_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_license_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_ok_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_page6_back_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_check_availability_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_register_password_confirm_entry_changed
                                        (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_password_entry_changed              (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_unregistered_login_checkbox_toggled (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_register_password_entry_changed     (GtkEditable     *editable,
                                        gpointer         user_data);
